@@ -52,6 +52,91 @@ static char     *mmd_parse_link(char *lineptr, char **text, char **url);
 static void     mmd_remove(mmd_t *node);
 
 
+/*
+ * 'mmdCopyAllText()' - Make a copy of all the text under a given node.
+ *
+ * The returned string must be freed using free().
+ */
+
+char *					/* O - Copied string */
+mmdCopyAllText(mmd_t *node)		/* I - Parent node */
+{
+  char		*all = NULL,		/* String buffer */
+		*allptr = NULL,		/* Pointer into string buffer */
+		*temp;			/* Temporary pointer */
+  size_t	allsize = 0,		/* Size of "all" buffer */
+		textlen;		/* Length of "text" string */
+  mmd_t		*current,		/* Current node */
+		*next;			/* Next node */
+
+
+  current = mmdGetFirstChild(node);
+
+  while (current != node)
+  {
+    if (current->text)
+    {
+     /*
+      * Append this node's text to the string...
+      */
+
+      textlen = strlen(current->text);
+
+      if (allsize == 0)
+      {
+        allsize = textlen + current->whitespace + 1;
+        all     = malloc(allsize);
+        allptr  = all;
+
+	if (!all)
+	  return (NULL);
+      }
+      else
+      {
+        allsize += textlen + current->whitespace;
+        temp    = realloc(all, allsize);
+
+        if (!temp)
+        {
+          free(all);
+          return (NULL);
+        }
+
+        allptr = temp + (allptr - all);
+        all    = temp;
+      }
+
+      if (current->whitespace)
+        *allptr++ = ' ';
+
+      memcpy(allptr, current->text, textlen);
+      allptr += textlen;
+    }
+
+   /*
+    * Find the next logical node...
+    */
+
+    if ((next = mmdGetNextSibling(current)) == NULL)
+    {
+      next = mmdGetParent(current);
+
+      while (next && next != node && mmdGetNextSibling(next) == NULL)
+	next = mmdGetParent(next);
+
+      if (next != node)
+        next = mmdGetNextSibling(next);
+    }
+
+    current = next;
+  }
+
+  *allptr = '\0';
+
+  return (all);
+}
+
+
 /*
  * 'mmdFree()' - Free a markdown tree.
  */
@@ -295,7 +380,7 @@ mmdLoadFile(FILE *fp)                   /* I - File to load */
                 *lineend;               /* End of line */
   int           blank_code = 0;         /* Saved indented blank code line */
   mmd_type_t	columns[256];		/* Alignment of table columns */
-  int		rows;			/* Number of rows in table */
+  int		rows = 0;		/* Number of rows in table */
 
 
  /*
@@ -446,7 +531,7 @@ mmdLoadFile(FILE *fp)                   /* I - File to load */
       int	col;			/* Current column */
       char	*start,			/* Start of column/cell */
 		*end;			/* End of column/cell */
-      mmd_t	*row,			/* Current row */
+      mmd_t	*row = NULL,		/* Current row */
 		*cell;			/* Current cell */
 
 //      fprintf(stderr, "TABLE current=%p (%d), rows=%d\n", current, current->type, rows);
